@@ -149,6 +149,57 @@ elseif($_REQUEST['set']=='imei'){
 	}
 	else echo "ERROR sim_name error!";
 }
+elseif($_REQUEST['reset']=='limit'){
+
+	$db->query("update sim set no_ring_remain=0,no_answer_remain=0,short_call_remain=0,remain_time=time_limit,count_remain=count_limit,no_connected_remain=no_connected_limit");
+
+	$query=$db->query("select sim.*,password from sim left join sim_bank on sim.bank_name=sim_bank.name");
+	while($row=$db->fetch_array($query)) {
+		if($row['imei']==NULL) $row['imei'] = "000000000000000";
+		$imei_len=strlen($row['imei']);
+		if($imei_len<15) $row['imei'] = sprintf("%15s",$row['imei']."000000000000000");
+		if($row['remain_time']==NULL || $row['remain_time'] <-1 ) $row['remain_time'] = -1;
+		$send[]=my_pack($row, SIM_ADD);
+	}
+	echo "OK.reset limit";
+	sendto_xchanged($send);
+}
+elseif($_REQUEST['get']=="hbfail"){
+	if($_REQUEST['t']){
+		sscanf($_REQUEST['t'], "%d:%d-%d:%d", $h,$m,$h1,$m1);
+		$t=$h*3600+$m*60;
+		$t1=$h1*3600+$m1*60;
+		$query=$db->query("select log,value from logs where `date`>=(CURDATE()+INTERVAL $t SECOND) and `date`<(CURDATE()+INTERVAL $t1 SECOND) and log like 'auto dial:%'");
+	}else $query=$db->query("select log,value from logs where `date`>now()-3600 and log like 'auto dial:%'");
+	while($row=$db->fetch_array($query)) {
+		if($row['value']=='0') {
+			sscanf($row['log'], "auto dial:%[^ ]", $num);
+			$num_ok[$num]=1;
+		}
+		else if($row['value']=='-1'){
+			sscanf($row['log'], "auto dial:%[^ ]", $num);
+			$num_fail[$num]=1;
+		}
+	}
+	foreach($num_fail as $num => $value){
+		//if(!array_key_exists($num, $num_ok)) 
+		echo "$num\n";
+	}
+}
+elseif($_REQUEST['get']=='rbin'){
+        //if($_REQUEST[sig]) $where=" and csq=$_REQUEST[sig]";
+        if($_REQUEST['line']) $where.=" and line_name='$_REQUEST[line]'";
+        if($_REQUEST['sig']) $where.=" and csq='$_REQUEST[sig]'";
+        if($_REQUEST['op']) $where.=" and oper='$_REQUEST[op]'";
+        if($_REQUEST['lst']) $where.=" and line_status='$_REQUEST[lst]'";
+        if($_REQUEST['gst']) $where.=" and gsm_status='$_REQUEST[gst]'";
+        if($_REQUEST['state']) $where.=" and call_state='$_REQUEST[state]'";
+        $query=$db->query("select line_name,csq,oper,line_status,gsm_status,call_state from device_line where line_name != '' $where");
+        while($row=@$db->fetch_array($query)) {
+      //echo "$row[0] $row[1] $row[2] $row[3] $row[4] $row[5];\n";
+      echo $row[0].",".$row[1].",".$row[2].",".$row[3].",".$row[4].",".$row[5].";";
+     }
+}
 
 ?>
 
